#!/bin/sh
# Default acpi script that takes an entry for all actions

set $*

case "$1" in
	button)
		case "$2" in
			power)	/sbin/shutdown -h now "Power button pressed"
				;;
			*)	logger "ACPI action $2 is not defined"
				;;
		esac
		;;

	*)
		logger "ACPI group $1 / action $2 is not defined"
		;;
esac
